<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}


if ( ! class_exists( 'Productive_Theme_Customiser_Contact' ) ) {
    
    /**
     * Productive_Theme_Customiser_Contact
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Contact extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            // See common for Panels
            // 
            // Section
            $wp_customise->add_section(
                'productive_ecommerce_contact_options',
                array(
                    'title' => esc_html__( 'Contact Options', 'productive-ecommerce' ),
                    'description' => '',
                    'panel' => 'productive_ecommerce_theme_options',
                    'priority' => 70,
                    'capability' => 'edit_theme_options',
                )
                );
            
            // add a setting for productive_ecommerce_contact_intro_1, below.
            $wp_customise->add_setting(
                'productive_ecommerce_contact_intro_1',
                array(
                    'type' => 'theme_mod',
                    'default' => esc_html__( 'Please complete the form and we will get back to you soon.', 'productive-ecommerce' ),
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_html'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_contact_intro_1',
                array(
                    'type' => 'textarea',
                    'priority' => 10,
                    'section' => 'productive_ecommerce_contact_options',
                    'label' => esc_html__( 'Contact page intro', 'productive-ecommerce' ),
                    'description' => esc_html__( '', 'productive-ecommerce' ),
                )
                );
            
            // add a setting for productive_ecommerce_contact_ask_for_visitor_phone control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_contact_ask_for_visitor_phone',
                array(
                    'type' => 'theme_mod',
                    'default' => false,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_contact_ask_for_visitor_phone',
                array(
                    'type' => 'checkbox',
                    'priority' => 20,
                    'section' => 'productive_ecommerce_contact_options',
                    'label' => esc_html__( 'Ask for phone number?', 'productive-ecommerce' ),
                    'description' => esc_html__( 'Ask your visitors to supply phone number in contact form?', 'productive-ecommerce' ),
                )
                );
                
            // add a setting for productive_ecommerce_contact_email, below.
            $wp_customise->add_setting(
                'productive_ecommerce_contact_email',
                array(
                    'type' => 'theme_mod',
                    'default' => '',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_no_html'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_contact_email',
                array(
                    'type' => 'text',
                    'priority' => 30,
                    'section' => 'productive_ecommerce_contact_options',
                    'label' => esc_html__( 'Email address', 'productive-ecommerce' ),
                    'description' => '',
                )
                );
            
            // add a setting for productive_ecommerce_contact_phone, below.
            $wp_customise->add_setting(
                'productive_ecommerce_contact_phone',
                array(
                    'type' => 'theme_mod',
                    'default' => '',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_no_html'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_contact_phone',
                array(
                    'type' => 'text',
                    'priority' => 40,
                    'section' => 'productive_ecommerce_contact_options',
                    'label' => esc_html__( 'Phone number', 'productive-ecommerce' ),
                    'description' => '',
                )
                );
            
            // add a setting for productive_ecommerce_contact_address, below.
            $wp_customise->add_setting(
                'productive_ecommerce_contact_address',
                array(
                    'type' => 'theme_mod',
                    'default' => '',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_no_html'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_contact_address',
                array(
                    'type' => 'text',
                    'priority' => 50,
                    'section' => 'productive_ecommerce_contact_options',
                    'label' => esc_html__( 'Address', 'productive-ecommerce' ),
                    'description' => '',
                )
                );
            
            // add a setting for productive_ecommerce_contact_country, below.
            $wp_customise->add_setting(
                'productive_ecommerce_contact_country',
                array(
                    'type' => 'theme_mod',
                    'default' => '',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_no_html'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_contact_country',
                array(
                    'type' => 'text',
                    'priority' => 60,
                    'section' => 'productive_ecommerce_contact_options',
                    'label' => esc_html__( 'Country', 'productive-ecommerce' ),
                    'description' => '',
                )
                );
            
            // add a setting for productive_ecommerce_contact_postcode, below.
            $wp_customise->add_setting(
                'productive_ecommerce_contact_postcode',
                array(
                    'type' => 'theme_mod',
                    'default' => '',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_no_html'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_contact_postcode',
                array(
                    'type' => 'text',
                    'priority' => 70,
                    'section' => 'productive_ecommerce_contact_options',
                    'label' => esc_html__( 'Postal Code', 'productive-ecommerce' ),
                    'description' => '',
                )
                );
            
        }
        
    } // End of class.
    
    // add hook for the class.
    add_action( 'customize_register', array( 'Productive_Theme_Customiser_Contact', 'register' ) );
    
} // End of if class exists
