<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}


if ( ! class_exists( 'Productive_Theme_Customiser_Social' ) ) {
    
    /**
     * Productive_Theme_Customiser_Social
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Social extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            // See common for Panels
            // 
            // Section
            $wp_customise->add_section(
                'productive_ecommerce_social_options',
                array(
                    'title' => esc_html__( 'Social Media Options', 'productive-ecommerce' ),
                    'description' => esc_html__( 'Add url for the social medi websites that you need. Empty boxes will be hidden.', 'productive-ecommerce' ),
                    'panel' => 'productive_ecommerce_theme_options',
                    'priority' => 60,
                    'capability' => 'edit_theme_options',
                )
                );
            
            // add a setting for productive_ecommerce_social_facebook, below.
            $wp_customise->add_setting(
                'productive_ecommerce_social_facebook',
                array(
                    'type' => 'theme_mod',
                    'default' => esc_html__( '', 'productive-ecommerce' ),
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_no_html'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_social_facebook',
                array(
                    'type' => 'text',
                    'priority' => 10,
                    'section' => 'productive_ecommerce_social_options',
                    'label' => esc_html__( 'Facebook Url', 'productive-ecommerce' ),
                    'description' => '',
                )
                );
            
            // add a setting for productive_ecommerce_social_youtube, below.
            $wp_customise->add_setting(
                'productive_ecommerce_social_youtube',
                array(
                    'type' => 'theme_mod',
                    'default' => esc_html__( '', 'productive-ecommerce' ),
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_no_html'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_social_youtube',
                array(
                    'type' => 'text',
                    'priority' => 20,
                    'section' => 'productive_ecommerce_social_options',
                    'label' => esc_html__( 'YouTube Url', 'productive-ecommerce' ),
                    'description' => '',
                )
                );

            // add a setting for productive_ecommerce_social_twitter, below.
            $wp_customise->add_setting(
                'productive_ecommerce_social_twitter',
                array(
                    'type' => 'theme_mod',
                    'default' => esc_html__( '', 'productive-ecommerce' ),
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_no_html'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_social_twitter',
                array(
                    'type' => 'text',
                    'priority' => 30,
                    'section' => 'productive_ecommerce_social_options',
                    'label' => esc_html__( 'Twitter Url', 'productive-ecommerce' ),
                    'description' => '',
                )
                );
            
            // add a setting for productive_ecommerce_social_pinterest, below.
            $wp_customise->add_setting(
                'productive_ecommerce_social_pinterest',
                array(
                    'type' => 'theme_mod',
                    'default' => esc_html__( '', 'productive-ecommerce' ),
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_no_html'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_social_pinterest',
                array(
                    'type' => 'text',
                    'priority' => 40,
                    'section' => 'productive_ecommerce_social_options',
                    'label' => esc_html__( 'Pinterest Url', 'productive-ecommerce' ),
                    'description' => '',
                )
                );
            
            // add a setting for productive_ecommerce_social_instagram, below.
            $wp_customise->add_setting(
                'productive_ecommerce_social_instagram',
                array(
                    'type' => 'theme_mod',
                    'default' => esc_html__( '', 'productive-ecommerce' ),
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_no_html'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_social_instagram',
                array(
                    'type' => 'text',
                    'priority' => 50,
                    'section' => 'productive_ecommerce_social_options',
                    'label' => esc_html__( 'Instagram Url', 'productive-ecommerce' ),
                    'description' => '',
                )
                );            
            
            // add a setting for productive_ecommerce_post_archive_title_color control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_post_social_icons_color',
                array(
                    'type' => 'theme_mod',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'default'              => '#ffffff',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_color'),
                )
                );
            
            $wp_customise->add_control(
                new WP_Customize_Color_Control(
                    $wp_customise,
                    'productive_ecommerce_post_social_icons_color',
                    array(
                        'priority' => 80,
                        'label' => esc_html__( 'Social Media Icons Colour', 'productive-ecommerce' ),
                        'section' => 'productive_ecommerce_social_options',
                    )
                    )
                );
            
            
        }
        
    } // End of class.
    
    // add hook for the class.
    add_action( 'customize_register', array( 'Productive_Theme_Customiser_Social', 'register' ) );
    
} // End of if class exists
